@@ -15,19 +15,6 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
     mx = 0; my = 0; mz = 0;
     proximity = false;
 
-    sw = new SettingsWindow(this);
-    sw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
-    wd = new WeightDialog(this);
-    wd->hide();
-
     xml = new XML();
 
     vLayout = new QVBoxLayout;
@@ -93,6 +80,11 @@ ExerciseWindow::ExerciseWindow(QWidget *parent) :
 
 }
 
+void ExerciseWindow::sendClosed()
+{
+    emit closed();
+}
+
 void ExerciseWindow::loadExercise(QList<QString> name)
 {
     QDBusConnection::sessionBus().send(lock);
@@ -144,29 +136,37 @@ void ExerciseWindow::changeEvent(QEvent *event)
 
 void ExerciseWindow::showNewIngredient()
 {
+    niw = new NewIngredientWindow(this);
     niw->load();
     niw->show();
 }
+
+void ExerciseWindow::showHistory()
+{
+    hw = new HistoryWindow(this);
+    hw->load();
+    hw->show();
+}
+
 void ExerciseWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void ExerciseWindow::showNewExercise()
 {
+    nw = new NewExerciseWindow(this);
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
     nw->load();
     nw->show();
 }
 
-void ExerciseWindow::showHistory()
-{
-    hw->load();
-    hw->show();
-}
-
 void ExerciseWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
