@@ -6,18 +6,8 @@ InfoMotionWindow::InfoMotionWindow(QWidget *parent) :
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    sw = new SettingsWindow(this);
-    sw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
-    mw = new MotionWindow(this);
+
     mw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
     xml = new XML();
 
     QWidget *widget = new QWidget();
@@ -36,31 +26,49 @@ InfoMotionWindow::InfoMotionWindow(QWidget *parent) :
     createMenu();
 }
 
-void InfoMotionWindow::showHistory()
+void InfoMotionWindow::sendClosed()
 {
-    hw->load();
-    hw->show();
+    emit closed();
+}
+
+void InfoMotionWindow::sendLandscape()
+{
+    emit landscape();
 }
 
 void InfoMotionWindow::showNewIngredient()
 {
+    niw = new NewIngredientWindow(this);
     niw->load();
     niw->show();
 }
+
+void InfoMotionWindow::showHistory()
+{
+    hw = new HistoryWindow(this);
+    hw->load();
+    hw->show();
+}
+
 void InfoMotionWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void InfoMotionWindow::showNewExercise()
 {
+    nw = new NewExerciseWindow(this);
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
     nw->load();
     nw->show();
 }
 
 void InfoMotionWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
@@ -100,6 +108,9 @@ void InfoMotionWindow::createActions()
 
 void InfoMotionWindow::startExercise()
 {
+    mw = new MotionWindow(this);
+    connect(mw,SIGNAL(closed()),this,SLOT(sendClosed()));
+    connect(mw,SIGNAL(landscape()),this, SLOT(sendLandscape()));
     mw->load(name);
     mw->show();
 }
