@@ -10,18 +10,6 @@ InfoWindow::InfoWindow(QWidget *parent) :
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
 
-    sw = new SettingsWindow(this);
-    sw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
-    ew = new ExerciseWindow(this);
-    ew->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
     xml = new XML();
 
 
@@ -74,6 +62,17 @@ InfoWindow::InfoWindow(QWidget *parent) :
     createMenu();
 
     connect(QApplication::desktop(), SIGNAL(resized(int)), this, SLOT(orientationChanged()));
+
+}
+
+void InfoWindow::sendClosed()
+{
+    emit closed();
+}
+
+void InfoWindow::sendLandscape()
+{
+    emit landscape();
 }
 
 void InfoWindow::orientationChanged()
@@ -105,31 +104,39 @@ void InfoWindow::orientationChanged()
     lblInfo->setPixmap(bild);
 }
 
+void InfoWindow::showNewIngredient()
+{
+    niw = new NewIngredientWindow(this);
+    niw->load();
+    niw->show();
+}
+
 void InfoWindow::showHistory()
 {
+    hw = new HistoryWindow(this);
     hw->load();
     hw->show();
 }
 
-void InfoWindow::showNewIngredient()
-{
-    niw->load();
-    niw->show();
-}
 void InfoWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void InfoWindow::showNewExercise()
 {
+    nw = new NewExerciseWindow(this);
+    emit landscape();
+    connect(nw,SIGNAL(closed()),this,SLOT(sendClosed()));
     nw->load();
     nw->show();
 }
 
 void InfoWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
@@ -192,7 +199,6 @@ void InfoWindow::loadExercise(QString name)
     status[1] = list.takeFirst();
     status[2] = list.takeFirst();
 
-
     list = xml->loadSettings();
     if(list.isEmpty())
         return;
@@ -206,6 +212,7 @@ void InfoWindow::loadExercise(QString name)
     reps[1] = list.takeLast();
     reps[0] = list.takeLast();
 
+
     if(currentReps == "Low")
     {
         if(weight[0] != "0")
@@ -241,7 +248,6 @@ void InfoWindow::loadExercise(QString name)
 
     txtInfo->setText(info);
 
-
 }
 
 void InfoWindow::startExercise()
@@ -249,6 +255,9 @@ void InfoWindow::startExercise()
     QList <QString> list;
     list.append(exerciseName);
 
+    ew = new ExerciseWindow(this);
+    connect(ew,SIGNAL(closed()),this,SLOT(sendClosed()));
+    connect(ew,SIGNAL(landscape()),this, SLOT(sendLandscape()));
     ew->loadExercise(list);
     ew->show();
 }
@@ -271,7 +280,7 @@ void InfoWindow::forward()
         //if(info[2] != "")
         //{
             QPixmap bild(w,h);
-            bild.load("/home/user/MyDocs/" + exerciseName + "2.png");
+            bild.load("/home/user/.qexercise/Images" + exerciseName + "2.png");
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
@@ -289,7 +298,7 @@ void InfoWindow::forward()
             gLayout->addWidget(lblInfo);
             lblInfo->show();
             QPixmap bild(w,h);
-            bild.load("/home/user/MyDocs/" + exerciseName + "1.png");
+            bild.load("/home/user/.qexercise/Images" + exerciseName + "1.png");
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
@@ -310,7 +319,7 @@ void InfoWindow::back()
             gLayout->addWidget(lblInfo);
             lblInfo->show();
             QPixmap bild(w,h);
-            bild.load("/home/user/MyDocs/" + exerciseName + "2.png");
+            bild.load("/home/user/.qexercise/Images" + exerciseName + "2.png");
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
@@ -334,7 +343,7 @@ void InfoWindow::back()
         //if(info[1] != "")
         //{
             QPixmap bild(w,h);
-            bild.load("/home/user/MyDocs/" + exerciseName + "1.png");
+            bild.load("/home/user/.qexercise/Images" + exerciseName + "1.png");
             bild = bild.scaled(w,h,Qt::KeepAspectRatio);
             lblInfo->setAlignment(Qt::AlignCenter);
             lblInfo->setPixmap(bild);
