@@ -6,13 +6,15 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
     QMainWindow(parent)
 {
     setAttribute(Qt::WA_Maemo5StackedWindow);
-    //setAttribute(Qt::WA_Maemo5LandscapeOrientation);
+    setAttribute(Qt::WA_Maemo5LandscapeOrientation);
     setWindowTitle("New exercise");
     xml = new XML();
 
     QWidget *widget = new QWidget();
     setCentralWidget(widget);
 
+
+
     QVBoxLayout *vLayout = new QVBoxLayout();
     txtName = new QLineEdit();
     txtName->setPlaceholderText("Name");
@@ -53,6 +55,7 @@ NewExerciseWindow::NewExerciseWindow(QWidget *parent) :
 
 void NewExerciseWindow::saveExercise()
 {
+
     if(txtName->text() == "")
     {
         QMaemo5InformationBox::information(this, "You must fill in name.", QMaemo5InformationBox::DefaultTimeout);
@@ -81,8 +84,19 @@ void NewExerciseWindow::saveExercise()
 
     QMaemo5InformationBox::information(this, "Exercise saved.",
                                                 QMaemo5InformationBox::DefaultTimeout);
-    this->hide();
+    emit closed();
+    this->destroy();
+
+    //this->hide();
 }
+
+#
+void NewExerciseWindow::closeEvent(QCloseEvent *event)
+{
+    emit closed();
+    event->accept();
+}
+
 void NewExerciseWindow::load()
 {
     btnGroup->setFocus();
