@@ -11,22 +11,6 @@ StartWindow::StartWindow(QWidget *parent) :
     QWidget *widget = new QWidget;
     setCentralWidget(widget);
 
-    fw = new FoodWindow(this);
-    fw->hide();
-    niw = new NewIngredientWindow(this);
-    niw->hide();
-    hw = new HistoryWindow(this);
-    hw->hide();
-    ww = new WeightWindow(this);
-    ww->hide();
-    sw = new SettingsWindow(this);
-    sw->hide();
-    nw = new NewExerciseWindow(this);
-    nw->hide();
-    npw = new NewProgramWindow(this);
-    npw->hide();
-    lw = new ListWindow(this);
-
     xml = new XML();
 
     QVBoxLayout *vLayout = new QVBoxLayout;
@@ -76,6 +60,13 @@ StartWindow::StartWindow(QWidget *parent) :
     resize(480,720);
 }
 
+
+void StartWindow::restorePortrait()
+{
+    setAttribute(Qt::WA_Maemo5PortraitOrientation,true);
+}
+
+
 QList <QString> StartWindow::getStats()
 {
     QList < QList <QString> > list;
@@ -125,20 +116,33 @@ StartWindow::~StartWindow()
 void StartWindow::checkIfFirstTime()
 {
     QFile file;
-    if(!file.exists("/home/user/MyDocs/exercises.xml"))
+    if(!file.exists("/home/user/.qexercise/exercises.xml"))
         xml->saveEx("Example","Arms","Biceps","Some info here");
 
-    if(!file.exists("/home/user/MyDocs/cardio.xml"))
+    if(!file.exists("/home/user/.qexercise/cardio.xml"))
         xml->saveCardio("Cardio");
 
-    //if(!file.exists("/home/user/MyDocs/history.xml"))
+    //if(!file.exists("/home/user/.qexercise/history.xml"))
         //return true;
-    //if(!file.exists("/home/user/MyDocs/program.xml"))
+    //if(!file.exists("/home/user/.qexercise/program.xml"))
         //return true;
 
-    if(!file.exists("/home/user/MyDocs/settings.xml"))
+    if(!file.exists("/home/user/.qexercise/settings.xml"))
         xml->saveSettings("0","0","0","1","1","1","1","Low","1","0","2500");
 
+
+    if(!QDir("/home/user/.qexercise").exists())
+    {
+        QDir().mkpath("/home/user/.qexercise");
+    }
+
+    if(!QDir("/home/user/.qexercise/Images").exists())
+    {
+        QDir().mkpath("/home/user/.qexercise/Images");
+    }
+
+
+
 }
 void StartWindow::changeEvent(QEvent *event)
 {
@@ -156,18 +160,23 @@ void StartWindow::changeEvent(QEvent *event)
 
 void StartWindow::showNewIngredient()
 {
+    niw = new NewIngredientWindow(this);
     niw->load();
     niw->show();
 }
 
 void StartWindow::showHistory()
 {
+    hw = new HistoryWindow(this);
     hw->load();
     hw->show();
 }
 
 void StartWindow::showFood()
 {
+    fw = new FoodWindow(this);
+    connect(fw,SIGNAL(closed()),this,SLOT(restorePortrait()));
+    connect(fw,SIGNAL(landscape()),this, SLOT(setLandscape()));
     fw->load();
     fw->show();
 
@@ -175,29 +184,47 @@ void StartWindow::showFood()
 
 void StartWindow::showWeight()
 {
+    ww = new WeightWindow(this);
+    connect(ww,SIGNAL(closed()),this,SLOT(restorePortrait()));
+    connect(ww,SIGNAL(landscape()),this, SLOT(setLandscape()));
     ww->show();
 }
 
+void StartWindow::setLandscape()
+{
+    setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+}
+
 void StartWindow::showCardio()
 {
+    lw = new ListWindow(this);
+    connect(lw,SIGNAL(closed()),this,SLOT(restorePortrait()));
+    connect(lw,SIGNAL(landscape()),this, SLOT(setLandscape()));
     lw->loadExercises("Cardio");
     lw->show();
 }
 
 void StartWindow::showSettings()
 {
+    sw = new SettingsWindow(this);
     sw->load();
     sw->show();
 }
 
 void StartWindow::showNewExercise()
 {
+
+    nw = new NewExerciseWindow(this);
+    connect(nw,SIGNAL(closed()),this,SLOT(restorePortrait()));
     nw->load();
     nw->show();
+
+    this->setAttribute(Qt::WA_Maemo5PortraitOrientation,false);
 }
 
 void StartWindow::showNewProgram()
 {
+    npw = new NewProgramWindow(this);
     npw->show();
 }
 
