@@ -72,6 +72,10 @@ private slots:
     void showNewExercise();
     void showNewProgram();
     void showNewIngredient();
+
+public slots:
+    void restorePortrait();
+    void setLandscape();
 };
 
 #endif // STARTWINDOW_H
